==> sign-center-api-0.0.2.2-20180428.084506-6-sources.jar: cn/com/duiba/sign/center/api/dto/SignOperatingPositionDto.java <==
package cn.com.duiba.sign.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaoxuda on 2017/12/5.
 */
public class SignOperatingPositionDto implements Serializable {
    private static final long serialVersionUID = 204026789024270567L;
    /**
     * 自增ID
     **/
    private Long id;
    /**
     * 标题文案
     **/
    private String title;
    /**
     * 跳转链接
     **/
    private String targetUrl;
    /**
     * 展示图片
     **/
    private String image;
    /**
     * 定向是否开启
     **/
    private Boolean directOpen;
    /**
     * 运营位是否开启
     */
    private Boolean statusOpen;
    /**
     * 创建时间
     **/
    private Date gmtCreate;
    /**
     * 修改时间
     **/
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTargetUrl() {
        return targetUrl;
    }

    public void setTargetUrl(String targetUrl) {
        this.targetUrl = targetUrl;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public Boolean getDirectOpen() {
        return directOpen;
    }

    public void setDirectOpen(Boolean directOpen) {
        this.directOpen = directOpen;
    }

    public Boolean getStatusOpen() {
        return statusOpen;
    }

    public void setStatusOpen(Boolean statusOpen) {
        this.statusOpen = statusOpen;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> sign-center-api-0.3.39.p1-sources.jar: cn/com/duiba/sign/center/api/dto/SignOperatingPositionDto.java <==
package cn.com.duiba.sign.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaoxuda on 2017/12/5.
 */
public class SignOperatingPositionDto implements Serializable {
    private static final long serialVersionUID = 204026789024270567L;
    /**
     * 自增ID
     **/
    private Long id;
    /**
     * 标题文案
     **/
    private String title;
    /**
     * 跳转链接
     **/
    private String targetUrl;
    /**
     * 展示图片
     **/
    private String image;
    /**
     * 定向是否开启
     **/
    private Boolean directOpen;
    /**
     * 运营位是否开启
     */
    private Boolean statusOpen;
    /**
     * 内容简介
     */
    private String content;
    /**
     * 创建时间
     **/
    private Date gmtCreate;
    /**
     * 修改时间
     **/
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTargetUrl() {
        return targetUrl;
    }

    public void setTargetUrl(String targetUrl) {
        this.targetUrl = targetUrl;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public Boolean getDirectOpen() {
        return directOpen;
    }

    public void setDirectOpen(Boolean directOpen) {
        this.directOpen = directOpen;
    }

    public Boolean getStatusOpen() {
        return statusOpen;
    }

    public void setStatusOpen(Boolean statusOpen) {
        this.statusOpen = statusOpen;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    @Override
    public String toString() {
        return "SignOperatingPositionDto{" +
                "id=" + id +
                ", title='" + title + '\'' +
                ", targetUrl='" + targetUrl + '\'' +
                ", image='" + image + '\'' +
                ", directOpen=" + directOpen +
                ", statusOpen=" + statusOpen +
                ", content='" + content + '\'' +
                ", gmtCreate=" + gmtCreate +
                ", gmtModified=" + gmtModified +
                '}';
    }
}
